# "cafle", a cash flow estimating tool

### cafle_module
"cafle" is a module that can be used to estimate the cash flow of a alternative investment when reviewing various investment project.
"Index", "Account" and "Loan" modules on "cafle" make it easier to estimate the cash flow of the project.

Financial planners and investors in charge of investment project frequently estimate cash flows for investment projects and review the adequacy of investment.
Since I mainly focus on real estate development projects and real estate investment, I prepared examples focusing on real estate development projects. However, I think it can be used where various financial models are needed, such as other infrastructure projects and new projects.

It often takes at least a few days to weeks to create a financial model with Excel, which also takes similar time to modify or create a new model for individual business and investment requirements. When the size of the model grows above a certain level, it is not common to interpret it or modify it.

This module will greatly save the time spent using Excel.